# inputs вашей GitHub Action

Входящие параметры описываются в наследнике 
[class ActionInputs][github_custom_actions.ActionInputs]

Если вы не создаете наследника, то можете получать входные параметры в стиле словаря.
Описав же наследника вы получите все преимущества автодополнения и проверки типов.

```python
class MyInputs(ActionInputs):
    my_input: str

action = ActionBase(inputs=MyInputs())
print(action.inputs.my_input)
print(action.inputs["my-input"])  # the same as above
```


Имена атрибутов преобразуются в `kebab-case`. 
Таким образом, `action.inputs.my_input` то же самое, что и `action.inputs["my-input"]`.

Если вам нужно получить доступ к входной переменной `my_input`, записанной в `snake_case`, 
вы должны использовать только доступ через словарь: `action.inputs["my_input"]`. 
Однако обычно в GitHub Actions имена входных переменных используют `kebab-case`.

По соглашению GitHub, все имена входных переменных для передачи через окружение преобразуются 
в верхний регистр с добавлением префикса "INPUT_". 

Таким образом, вход `actions.inputs.my_input` или `actions.inputs['my-input']` будет переменной `INPUT_MY-INPUT` в окружении. 
[ActionInputs][github_custom_actions.ActionInputs] автоматически выполняет преобразование.
Благодаря этому используя стиль словаря вы можете использовать обращаться к любым переменным окружения,
в том числе не описанным в атрибутах класса.

Используется ленивая загрузка значений. 
Таким образом, значение считывается из окружения, только когда оно запрашивается, и только один раз,
после чего запоминается во внутреннем словаре объекта.
